@@ -327,20 +327,14 @@ public class JpaTransactionManager {
 	 * @return callbackクラスのリスト
 	 */
 	private List<JpaTransactionCallback> getCallback() {
-		List<JpaTransactionCallback> callbacks = new ArrayList<JpaTransactionCallback>();
 
 		if (em.getProperties().containsKey(CALLBACK)) {
-			Object list = em.getProperties().get(CALLBACK);
-			if (list instanceof List) {
-				for (Object element : (List)list) {
-					if (element instanceof JpaTransactionCallback) {
-						callbacks.add((JpaTransactionCallback)element);
-					}
-				}
-			}
+			return (List<JpaTransactionCallback>)em.getProperties().get(CALLBACK);
+		}
+		else {
+			return new ArrayList<JpaTransactionCallback>();
 		}
 
-		return callbacks;
 	}
 
 	/**
