@@ -31,72 +31,91 @@ HOST=`hostname`
 ########################################
 
 # INFO
-MSG_I001="${PROG}    : shutdown Hinemos Manager"
-MSG_I002="waiting for Hinemos Manager to stop..."
-MSG_I003="Hinemos Manager stopped"
+MSG_I001="waiting for Hinemos Manager to stop..."
+MSG_I002="Hinemos Manager stopped"
 
 # WARN
 #MSG_W001="xxx"
 
 # ERROR
-MSG_E001="usage : ${PROG} (no argument)"
-MSG_E002="incorrect user(${USER}). please check variable HINEMOS_JBOSS_USER (${HINEMOS_HOME}/hinemos.cfg).";
-MSG_E003="failed to stop Hinemos Manager"
+MSG_E001="failed to stop Hinemos Manager"
 
 ########################################
 # Function
 ########################################
 
+function usage {
+	echo "usage : ${PROG} [-F]"
+	echo "options:"
+	echo "  -F   force startup without process dependency check"
+}
 
 ########################################
 # SHELL
 ########################################
 
-#
 # check argument
-#
-for ARGS in "$@"
+for OPT in $@
 do
-	case ${ARGS} in
-		*)
-			Logging "${MSG_E001}"
-			Logging "${MSG_I001}"
-			exit -1
+	case ${OPT} in
+		--help)
+			usage
+			exit 0
 			;;
 	esac
 done
 
-#
-# check user executed
-#
-if [ "x"${USER} != "x"${HINEMOS_JBOSS_USER} ]
+# option check
+OPT_FORCE=""
+while getopts F OPT
+do
+	case ${OPT} in
+		F)
+			OPT_FORCE="-F"
+			;;
+		*)
+			ExitIllegalOptionErrorWithoutLogger
+			;;
+	esac
+done
+
+shift $(( $OPTIND - 1 ))
+
+if [ ! $# = 0 ]
 then
-	Logging "${MSG_E002}"
-	exit -2
+	ExitIllegalArgumentError
 fi
 
-Logging "${MSG_I002}" && echo
+# check user executed
+CheckUser ${JVM_USER}
 
-# shutdown JBoss
-${HINEMOS_HOME}/bin/jboss_stop.sh
+Logging "${MSG_I001}"
+echo
+
+# shutdown JVM
+${HINEMOS_HOME}/bin/jvm_stop.sh ${OPT_FORCE}
 
 RET=$?
 if [ ${RET} -ne 0 ]
 then
-	echo && Logging "${MSG_E003}"
+	echo
+	Logging "${MSG_E001}"
 	exit ${RET}
 fi
 
 # shutdown PostgreSQL
-${HINEMOS_HOME}/bin/pg_stop.sh
+echo
+${HINEMOS_HOME}/bin/pg_stop.sh ${OPT_FORCE}
 
 RET=$?
 if [ ${RET} -ne 0 ]
 then
-	echo && Logging "${MSG_E003}"
+	echo
+	Logging "${MSG_E001}"
 	exit ${RET}
 fi
 
-echo && Logging "${MSG_I003}"
+echo
+Logging "${MSG_I002}"
 
 exit 0
